@@ -46,6 +46,7 @@ class DashboardApp {
         this.tokenRefreshTimer = null;
         this.refreshInFlight = false;
         this.chargers = new Map();
+        this.expandedChargers = new Set();
         this.cars = new Map();
         this.sessions = [];
         this.activePanel = null;
@@ -64,15 +65,12 @@ class DashboardApp {
             { key: 'name', label: 'Name' },
             { key: 'assignedCar', label: 'Car' },
             { key: 'energyManagerMode', label: 'Energy manager mode' },
-            { key: 'connected', label: 'Connected' },
+            { key: 'connected', label: 'Reachable' },
             { key: 'status', label: 'Status' },
             { key: 'chargingCurrent', label: 'Charging current' },
             { key: 'chargingPhases', label: 'Charging phases' },
             { key: 'currentPower', label: 'Current power' },
-            { key: 'sessionEnergy', label: 'Session energy' },
-            { key: 'version', label: 'Version' },
-            { key: 'temperature', label: 'Temperature' },
-            { key: 'digitalInputMode', label: 'Digital input' }
+            { key: 'sessionEnergy', label: 'Session energy' }
         ];
 
         this.translateDocument();
@@ -135,8 +133,9 @@ class DashboardApp {
                 'chargers.columns.name': 'Name',
                 'chargers.columns.car': 'Car',
                 'chargers.columns.energyManagerMode': 'Energy manager mode',
-                'chargers.columns.connected': 'Connected',
+                'chargers.columns.connected': 'Reachable',
                 'chargers.columns.status': 'Status',
+                'chargers.columns.lastStatusUpdate': 'Last status update',
                 'chargers.columns.chargingCurrent': 'Charging current',
                 'chargers.columns.chargingPhases': 'Charging phases',
                 'chargers.columns.currentPower': 'Current power',
@@ -144,6 +143,14 @@ class DashboardApp {
                 'chargers.columns.version': 'Version',
                 'chargers.columns.temperature': 'Temperature',
                 'chargers.columns.digitalInputMode': 'Digital input',
+                'chargerStatus.Init': 'Initializing',
+                'chargerStatus.A1': 'Charger ready',
+                'chargerStatus.A2': 'Charger ready',
+                'chargerStatus.B1': 'Car connected, autorization required',
+                'chargerStatus.B2': 'Car connected',
+                'chargerStatus.C1': 'Charging pause, car ready',
+                'chargerStatus.C2': 'Charging',
+                'chargerStatus.F': 'Error',
 
                 'sessions.history': 'History',
                 'sessions.title': 'Charging sessions',
@@ -151,7 +158,7 @@ class DashboardApp {
                 'sessions.allCars': 'All cars',
                 'sessions.filterStartDate': 'Start date',
                 'sessions.filterEndDate': 'End date',
-                'sessions.fetch': 'Fetch sessions',
+                'sessions.fetch': 'Refresh view',
                 'sessions.downloadCsv': 'Download CSV',
                 'sessions.helper': 'Optionally filter charging sessions by car and time range before downloading.',
                 'sessions.columns.name': 'Name',
@@ -186,6 +193,7 @@ class DashboardApp {
                 'help.referenceBullet1': 'The dashboard keeps one row per charger ID and updates it with backend notifications.',
                 'help.referenceBullet2': 'Columns follow the order defined by <code>EvDashEngine::packCharger</code> so new properties show up automatically.',
                 'help.referenceBullet3': 'Branding (colours, fonts) is managed via CSS variables at the top of this file for easy overrides.',
+                'help.referenceBullet4': 'Select a charger row to expand additional charger details.',
 
                 'easterEgg.hiddenTreat': 'Hidden treat',
                 'easterEgg.title': 'Grid Dash',
@@ -274,8 +282,9 @@ class DashboardApp {
                 'chargers.columns.name': 'Name',
                 'chargers.columns.car': 'Fahrzeug',
                 'chargers.columns.energyManagerMode': 'Energiemanager-Modus',
-                'chargers.columns.connected': 'Verbunden',
+                'chargers.columns.connected': 'Erreichbar',
                 'chargers.columns.status': 'Status',
+                'chargers.columns.lastStatusUpdate': 'Letzte Statusaktualisierung',
                 'chargers.columns.chargingCurrent': 'Ladestrom',
                 'chargers.columns.chargingPhases': 'Ladephasen',
                 'chargers.columns.currentPower': 'Aktuelle Leistung',
@@ -283,6 +292,14 @@ class DashboardApp {
                 'chargers.columns.version': 'Version',
                 'chargers.columns.temperature': 'Temperatur',
                 'chargers.columns.digitalInputMode': 'Digitaler Eingang',
+                'chargerStatus.Init': 'Initialisierung',
+                'chargerStatus.A1': 'Ladestation bereit',
+                'chargerStatus.A2': 'Ladestation bereit',
+                'chargerStatus.B1': 'Fahrzeug verbunden, Autorisierung erforderlich',
+                'chargerStatus.B2': 'Fahrzeug verbunden',
+                'chargerStatus.C1': 'Ladepause, Fahrzeug bereit',
+                'chargerStatus.C2': 'Laden',
+                'chargerStatus.F': 'Fehler',
 
                 'sessions.history': 'Historie',
                 'sessions.title': 'Ladevorgänge',
@@ -290,7 +307,7 @@ class DashboardApp {
                 'sessions.allCars': 'Alle Fahrzeuge',
                 'sessions.filterStartDate': 'Startdatum',
                 'sessions.filterEndDate': 'Enddatum',
-                'sessions.fetch': 'Ladevorgänge laden',
+                'sessions.fetch': 'Ansicht aktualisieren',
                 'sessions.downloadCsv': 'CSV herunterladen',
                 'sessions.helper': 'Optional nach Fahrzeug und Zeitraum filtern, bevor du die CSV herunterlädst.',
                 'sessions.columns.name': 'Name',
@@ -325,6 +342,7 @@ class DashboardApp {
                 'help.referenceBullet1': 'Das Dashboard hält eine Zeile pro Ladestations-ID und aktualisiert sie über Backend-Benachrichtigungen.',
                 'help.referenceBullet2': 'Die Spalten folgen der Reihenfolge aus <code>EvDashEngine::packCharger</code>, sodass neue Eigenschaften automatisch erscheinen.',
                 'help.referenceBullet3': 'Branding (Farben, Schrift) wird über CSS-Variablen am Anfang dieser Datei gesteuert.',
+                'help.referenceBullet4': 'Wähle eine Ladestationszeile aus, um zusätzliche Details einzublenden.',
 
                 'easterEgg.hiddenTreat': 'Verstecktes Extra',
                 'easterEgg.title': 'Grid Dash',
@@ -494,6 +512,27 @@ class DashboardApp {
                     this.stopEasterEggGame();
             });
         }
+
+        if (this.elements.chargerTableBody) {
+            this.elements.chargerTableBody.addEventListener('click', event => {
+                const targetRow = event.target ? event.target.closest('tr[data-charger-id]') : null;
+                if (!targetRow || !targetRow.dataset || !targetRow.dataset.chargerId)
+                    return;
+                this.toggleChargerDetails(targetRow.dataset.chargerId);
+            });
+
+            this.elements.chargerTableBody.addEventListener('keydown', event => {
+                if (!event || (event.key !== 'Enter' && event.key !== ' '))
+                    return;
+
+                const targetRow = event.target ? event.target.closest('tr[data-charger-id]') : null;
+                if (!targetRow || !targetRow.dataset || !targetRow.dataset.chargerId)
+                    return;
+
+                event.preventDefault();
+                this.toggleChargerDetails(targetRow.dataset.chargerId);
+            });
+        }
     }
 
     initializePanelNavigation() {
@@ -1125,8 +1164,12 @@ class DashboardApp {
 
         let row = this.findChargerRow(key);
         if (!row || forceCreate) {
-            if (row && row.parentElement)
+            if (row && row.parentElement) {
+                const detailsRow = this.findChargerDetailsRow(key);
+                if (detailsRow && detailsRow.parentElement)
+                    detailsRow.parentElement.removeChild(detailsRow);
                 row.parentElement.removeChild(row);
+            }
             row = this.buildChargerRow(charger);
             this.elements.chargerTableBody.appendChild(row);
         } else {
@@ -1140,12 +1183,17 @@ class DashboardApp {
             });
         }
 
+        this.syncChargerDetailsVisibility(key);
         this.toggleChargerEmptyState();
     }
 
     buildChargerRow(charger) {
         const row = document.createElement('tr');
+        row.classList.add('charger-row');
         row.dataset.chargerId = this.getChargerKey(charger) || '';
+        row.tabIndex = 0;
+        row.setAttribute('role', 'button');
+        row.setAttribute('aria-expanded', 'false');
         this.chargerColumns.forEach(column => {
             if (column.hidden)
                 return;
@@ -1157,6 +1205,141 @@ class DashboardApp {
         return row;
     }
 
+    toggleChargerDetails(chargerId) {
+        if (!chargerId)
+            return;
+
+        const key = this.getChargerKey(chargerId);
+        if (!key)
+            return;
+
+        if (this.expandedChargers.has(key))
+            this.collapseChargerDetails(key);
+        else
+            this.expandChargerDetails(key);
+    }
+
+    expandChargerDetails(chargerId) {
+        if (!chargerId)
+            return;
+
+        const key = this.getChargerKey(chargerId);
+        if (!key)
+            return;
+
+        this.expandedChargers.add(key);
+        this.syncChargerDetailsVisibility(key);
+    }
+
+    collapseChargerDetails(chargerId) {
+        if (!chargerId)
+            return;
+
+        const key = this.getChargerKey(chargerId);
+        if (!key)
+            return;
+
+        this.expandedChargers.delete(key);
+        this.syncChargerDetailsVisibility(key);
+    }
+
+    syncChargerDetailsVisibility(chargerId) {
+        if (!chargerId || !this.elements.chargerTableBody)
+            return;
+
+        const key = this.getChargerKey(chargerId);
+        if (!key)
+            return;
+
+        const isExpanded = this.expandedChargers.has(key);
+        const row = this.findChargerRow(key);
+        if (row) {
+            row.classList.toggle('is-expanded', isExpanded);
+            row.setAttribute('aria-expanded', isExpanded ? 'true' : 'false');
+        }
+
+        const detailsRow = this.findChargerDetailsRow(key);
+        if (!isExpanded) {
+            if (detailsRow && detailsRow.parentElement)
+                detailsRow.parentElement.removeChild(detailsRow);
+            return;
+        }
+
+        if (!row)
+            return;
+
+        const ensured = detailsRow || this.buildChargerDetailsRow(key);
+        if (ensured && ensured !== detailsRow) {
+            this.elements.chargerTableBody.insertBefore(ensured, row.nextSibling);
+        }
+
+        this.updateChargerDetailsRow(key);
+    }
+
+    buildChargerDetailsRow(chargerId) {
+        const row = document.createElement('tr');
+        row.classList.add('charger-details-row');
+        row.dataset.chargerDetailsFor = this.getChargerKey(chargerId) || '';
+
+        const cell = document.createElement('td');
+        cell.colSpan = this.getVisibleChargerColumnCount();
+        const list = document.createElement('dl');
+        list.className = 'charger-details-list';
+        cell.appendChild(list);
+        row.appendChild(cell);
+        return row;
+    }
+
+    updateChargerDetailsRow(chargerId) {
+        if (!chargerId)
+            return;
+
+        const key = this.getChargerKey(chargerId);
+        if (!key || !this.expandedChargers.has(key))
+            return;
+
+        const charger = this.chargers && this.chargers.get(key) ? this.chargers.get(key) : null;
+        const detailsRow = this.findChargerDetailsRow(key);
+        if (!detailsRow)
+            return;
+
+        const list = detailsRow.querySelector('dl.charger-details-list');
+        if (!list)
+            return;
+
+        const items = [
+            { label: this.t('chargers.columns.lastStatusUpdate'), key: 'lastStatusUpdate' },
+            { label: this.t('chargers.columns.version'), key: 'version' },
+            { label: this.t('chargers.columns.temperature'), key: 'temperature' },
+            { label: this.t('chargers.columns.digitalInputMode'), key: 'digitalInputMode' }
+        ];
+
+        list.innerHTML = '';
+        items.forEach(item => {
+            const term = document.createElement('dt');
+            term.textContent = item.label;
+            const description = document.createElement('dd');
+            const value = charger && Object.prototype.hasOwnProperty.call(charger, item.key) ? charger[item.key] : null;
+            description.textContent = this.formatChargerValue(item.key, value);
+            list.appendChild(term);
+            list.appendChild(description);
+        });
+    }
+
+    findChargerDetailsRow(chargerId) {
+        if (!this.elements.chargerTableBody || !chargerId)
+            return null;
+
+        const normalizedId = typeof CSS !== 'undefined' && CSS.escape
+            ? CSS.escape(String(chargerId))
+            : String(chargerId).replace(/"/g, '\\"');
+        return this.elements.chargerTableBody.querySelector(`tr[data-charger-details-for="${normalizedId}"]`);
+    }
+
+    getVisibleChargerColumnCount() {
+        return this.chargerColumns.filter(column => !column.hidden).length;
+    }
+
     renderCellValue(cell, key, value) {
         if (!cell)
             return;
@@ -1184,10 +1367,14 @@ class DashboardApp {
         if (!key)
             return;
 
+        this.expandedChargers.delete(key);
         this.chargers.delete(key);
         const row = this.findChargerRow(key);
+        const detailsRow = this.findChargerDetailsRow(key);
         if (row && row.parentElement)
             row.parentElement.removeChild(row);
+        if (detailsRow && detailsRow.parentElement)
+            detailsRow.parentElement.removeChild(detailsRow);
 
         this.toggleChargerEmptyState();
     }
@@ -1196,7 +1383,8 @@ class DashboardApp {
         if (!this.elements.chargerTableBody)
             return;
 
-        const rows = this.elements.chargerTableBody.querySelectorAll('tr[data-charger-id]');
+        this.expandedChargers.clear();
+        const rows = this.elements.chargerTableBody.querySelectorAll('tr[data-charger-id], tr[data-charger-details-for]');
         rows.forEach(row => {
             if (row.parentElement)
                 row.parentElement.removeChild(row);
@@ -1337,10 +1525,54 @@ class DashboardApp {
         return unit ? `${rounded} ${unit}` : String(rounded);
     }
 
+    formatNumberMaxDecimals(value, unit, decimals = 2) {
+        if (!Number.isFinite(value))
+            return '—';
+
+        const factor = 10 ** decimals;
+        const rounded = Math.round(value * factor) / factor;
+        let text = rounded.toFixed(decimals).replace(/\.?0+$/, '');
+        if (text === '-0')
+            text = '0';
+        return unit ? `${text} ${unit}` : text;
+    }
+
+    coerceFiniteNumber(value) {
+        if (typeof value === 'number')
+            return Number.isFinite(value) ? value : null;
+
+        if (typeof value !== 'string')
+            return null;
+
+        const normalized = value.trim().replace(',', '.');
+        if (!normalized)
+            return null;
+
+        const parsed = Number.parseFloat(normalized);
+        return Number.isFinite(parsed) ? parsed : null;
+    }
+
     formatChargerValue(key, value) {
         if (value === null || value === undefined || value === '')
             return '—';
 
+        if (key === 'status') {
+            const code = String(value).trim();
+            const statusKeys = {
+                Init: 'chargerStatus.Init',
+                A1: 'chargerStatus.A1',
+                A2: 'chargerStatus.A2',
+                B1: 'chargerStatus.B1',
+                B2: 'chargerStatus.B2',
+                C1: 'chargerStatus.C1',
+                C2: 'chargerStatus.C2',
+                F: 'chargerStatus.F'
+            };
+            if (code in statusKeys)
+                return `${code}: ${this.t(statusKeys[code])}`;
+            return code || '—';
+        }
+
         if (key === 'energyManagerMode') {
             const modes = {
                 0: this.t('energyManagerMode.quick'),
@@ -1364,12 +1596,37 @@ class DashboardApp {
             return Number.isFinite(value) ? this.t('value.unknownWithValue', { value }) : '—';
         }
 
-        if ((key === 'currentPower' || key === 'sessionEnergy') && typeof value === 'number') {
+        if (key === 'lastStatusUpdate') {
+            const numeric = typeof value === 'string' ? Number.parseFloat(value) : value;
+            if (!Number.isFinite(numeric))
+                return '—';
+
+            const ms = numeric > 1e12 ? numeric : numeric * 1000;
+            const date = new Date(ms);
+            if (Number.isNaN(date.getTime()))
+                return '—';
+
+            const pad = part => String(part).padStart(2, '0');
+            const day = pad(date.getDate());
+            const month = pad(date.getMonth() + 1);
+            const year = date.getFullYear();
+            const hours = pad(date.getHours());
+            const minutes = pad(date.getMinutes());
+            const seconds = pad(date.getSeconds());
+
+            return `${day}.${month}.${year} ${hours}:${minutes}:${seconds}`;
+        }
+
+        if (key === 'currentPower' || key === 'sessionEnergy') {
+            const numericValue = this.coerceFiniteNumber(value);
+            if (numericValue === null)
+                return typeof value === 'string' ? value : '—';
+
             const unit = key === 'currentPower' ? 'kW' : 'kWh';
             if (key === 'currentPower')
-                return this.formatNumber(value / 1000, unit);
+                return numericValue >= 0 && numericValue < 50 ? `0 ${unit}` : this.formatNumberMaxDecimals(numericValue / 1000, unit, 2);
 
-            return this.formatNumber(value, unit);
+            return this.formatNumber(numericValue, unit);
         }
 
         if (typeof value === 'boolean')
